Todo
----
* Bugfix: Recalculate frames if offset is used.
* Add sequence to the CSV output.
* If possible, provide option to input multiple read lengths and offsets.
* No way to check if input BAM is RNA-Seq/Ribo-Seq (plot will still be generated in either case).
* Check if BAM is sorted.


